==> 4.7.4.tar.gz: terraform-provider-decort/samples/cloudbroker/extnet/resource_extnet_static_route/main.tf <==
/*
Пример использования
Ресурса extnet static routes
Ресурс позволяет:
1. Создавать static routes
2. Удалять static routes
3. Получать информацию о всех static routes в данном extnet
4. Предоставлять доступ виртуальным машинам к static routes
5. Удалять доступ виртуальным машинам к static routes
*/

#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source  = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "decort_cb_extnet_static_route" "sr" {
 
  #id extnet
  #обязательный параметр
  #тип - целое число
  extnet_id = 1111

  #destination network
  #обязательный параметр
  #тип - строка
  destination = "192.168.201.0"

  #destination network mask
  #обязательный параметр
  #тип - строка
  netmask  =   "255.255.255.255"

  #IP-адрес из пула свободных IP-адресов extnet ID
  #обязательный параметр
  #тип - строка
  gateway = "192.168.201.40"

  #список виртуальных машин, которым будет предоставлен доступ к роуту
  #опциональный параметр
  #тип - массив целых чисел
  #compute_ids = [111,222]
}

output "sr" {
  value = decort_cb_extnet_static_route.sr
}

==> 4.9.0.tar.gz: terraform-provider-decort/samples/cloudbroker/extnet/resource_extnet_static_route/main.tf <==
/*
Пример использования
Ресурса extnet static routes
Ресурс позволяет:
1. Создавать static routes
2. Удалять static routes
3. Получать информацию о всех static routes в данном extnet
4. Предоставлять доступ виртуальным машинам к static routes
5. Удалять доступ виртуальным машинам к static routes
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source  = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "decort_cb_extnet_static_route" "sr" {
  #id extnet
  #обязательный параметр
  #тип - целое число
  #используется при создании
  extnet_id = 1111

  #destination network
  #обязательный параметр
  #тип - строка
  #используется при создании
  destination = "192.168.201.0"

  #destination network mask
  #обязательный параметр
  #тип - строка
  #используется при создании
  netmask  =   "255.255.255.255"

  #ip-адрес из пула свободных IP-адресов extnet ID
  #обязательный параметр
  #тип - строка
  #используется при создании
  gateway = "192.168.201.40"

  #список виртуальных машин, которым будет предоставлен доступ к роуту
  #опциональный параметр
  #тип - массив целых чисел
  #используется при создании и обновлении
  #compute_ids = [111,222]
}

output "sr" {
  value = decort_cb_extnet_static_route.sr
}
